/// <reference types="node" />
import { EventEmitter } from 'events';
import { Commands, SocketPayloadsMap } from './types';
export interface IUWaveOptions {
    authImmediately?: boolean;
    credentials?: {
        email: string;
        password: string;
    };
    apiBaseUrl: string;
    wsConnectionString: string;
}
export declare class uWave {
    private jwt?;
    private socketToken?;
    private socket?;
    private emitter;
    options: IUWaveOptions;
    static KEEP_ALIVE_MESSAGE: string;
    constructor(options: IUWaveOptions);
    get isConnected(): boolean;
    login(email: string, password: string): Promise<{
        _id: string;
        username: string;
        slug: string;
        avatar: string;
        roles: string[];
        role: number;
        level: number;
        language: string;
        exiled: boolean;
        activePlaylist?: string | undefined;
        lastSeenAt: string;
        createdAt: string;
        updatedAT: string;
    }>;
    connect(): void;
    once<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    on<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    off<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    sendChat(message: string): void;
    vote(direction: 1 | -1): void;
    logout(): void;
    private connectSocket;
    private onSocketOpen;
    private onSocketClose;
    private onSocketError;
    private onSocketMessage;
    private emit;
    private send;
}
