"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uWave = void 0;
const WebSocket = require("ws");
const events_1 = require("events");
const actions_1 = require("./actions");
class uWave {
    constructor(options) {
        this.options = options;
        this.emitter = new events_1.EventEmitter();
        if (!process.env.UWAVE_API_BASE_URL) {
            process.env.UWAVE_API_BASE_URL = options.apiBaseUrl;
        }
        if (options.authImmediately && options.credentials) {
            const credentials = options.credentials;
            delete this.options.credentials;
            this.login(credentials.email, credentials.password).then(() => this.connect());
        }
    }
    get isConnected() {
        var _a;
        return ((_a = this.socket) === null || _a === void 0 ? void 0 : _a.readyState) === WebSocket.OPEN;
    }
    login(email, password) {
        return actions_1.login(email, password).then((res) => {
            this.jwt = res.meta.jwt;
            this.socketToken = res.meta.socketToken;
            this.jwt;
            this.socketToken;
            this.emit('login');
            return res.data;
        });
    }
    connect() {
        return this.connectSocket(this.options.wsConnectionString);
    }
    once(eventName, listener) {
        return this.emitter.on(eventName, listener);
    }
    on(eventName, listener) {
        return this.emitter.on(eventName, listener);
    }
    off(eventName, listener) {
        return this.emitter.off(eventName, listener);
    }
    sendChat(message) {
        return this.send({ command: 'sendChat', data: message });
    }
    vote(direction) {
        return this.send({ command: 'vote', data: direction });
    }
    logout() {
        return this.send({ command: 'logout' });
    }
    connectSocket(connectionString) {
        this.socket = new WebSocket(connectionString);
        this.socket.onopen = this.onSocketOpen.bind(this);
        this.socket.onclose = this.onSocketClose.bind(this);
        this.socket.onerror = this.onSocketError.bind(this);
        this.socket.onmessage = this.onSocketMessage.bind(this);
    }
    onSocketOpen( /* event: WebSocket.OpenEvent */) {
        this.emit('connected');
        if (this.socketToken && this.socket && this.isConnected) {
            this.socket.send(this.socketToken);
        }
    }
    onSocketClose(event) {
        this.emit('disconnected');
        console.log('closed', event);
    }
    onSocketError(event) {
        this.emit('error');
        console.log('error', event);
    }
    onSocketMessage(event) {
        if (event.data === uWave.KEEP_ALIVE_MESSAGE)
            return;
        if (typeof event.data !== 'string')
            return;
        let payload;
        try {
            payload = JSON.parse(event.data);
        }
        catch (err) {
            console.error(err);
            return;
        }
        switch (payload.command) {
            default:
                this.emit(payload.command, payload.data);
                break;
        }
    }
    emit(command, payload) {
        return this.emitter.emit(command, payload);
    }
    send(message) {
        if (!this.socket || this.socket.readyState !== WebSocket.OPEN)
            return;
        return this.socket.send(JSON.stringify(message));
    }
}
exports.uWave = uWave;
uWave.KEEP_ALIVE_MESSAGE = '-';
//# sourceMappingURL=index.js.map